@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.117-7-g4cf3986
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.118-5-gbfe9302
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.118';
+our $VERSION = '0.119';
 
 use Moose;
 with
@@ -255,7 +255,8 @@ sub configure
         [ 'Test::Pod::No404s'   => { ':version' => '1.003' } ],
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
-        [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1, version_extractor => 'Module::Metadata',
+        [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1,
+            version_extractor => ( ( any { $_ ne 'MakeMaker' } $self->installer ) ? 'Module::Metadata' : 'ExtUtils::MakeMaker' ),
             include => [ sort ( qw(autodie JSON::PP YAML), exists $removed{PodCoverageTests} ? () : 'Pod::Coverage' ) ] } ],
         [ 'Test::Portability'   => { ':version' => '2.000007' } ],
         [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
@@ -472,7 +473,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.118
+version 0.119
 
 =head1 SYNOPSIS
 
@@ -1070,12 +1071,16 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Randy Stauner Сергей Романов
+=for stopwords Graham Knop Randy Stauner Сергей Романов
 
 =over 4
 
 =item *
 
+Graham Knop <haarg@haarg.org>
+
+=item *
+
 Randy Stauner <rwstauner@cpan.org>
 
 =item *
